#
# spec file for package openucx
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           openucx
Summary:        Unifieid Communication X
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Version:        1.2.2
Release:        lp150.1.2
Url:            http://openucx.org/

#Git-Clone:	git://github.com/openucx/ucx
#Git-Web:	https://github.com/openucx/ucx
Source:         https://github.com/openucx/ucx/releases/download/v%version/ucx-%version.tar.gz
Patch1:         openucx-s390x-support.patch
BuildRequires:  autoconf >= 2.63
BuildRequires:  automake >= 1.10
BuildRequires:  binutils-devel
BuildRequires:  gcc-c++
BuildRequires:  libibverbs-devel
BuildRequires:  libnuma-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 %power64 x86_64 s390x

%description
UCX is a communication library implementing high-performance
messaging for MPI/PGAS frameworks.

%package tools
Summary:        OpenUCX utilities
Group:          System/Console

%description tools
Miscallaneous utilities for Unified Communication X.

%package -n libucm0
Summary:        Memory (un)happing hooks for Unified Communication X
Group:          System/Libraries

%description -n libucm0
libucm is a standalone non-unloadable library which installs hooks
for virtual memory changes in the current process. Then, it calls
user-defined callbacks, which may potentially override the default
behavior, or just passively listen and update their own data. libucm
does not use libuct, to avoid making it non-unloadable as well, and
impelements a basic logging service which is safe to use from malloc
hooks.

%package -n libucm-devel
Summary:        Development files for Unified Communication X Memory Hooks
Group:          Development/Libraries/C and C++
Requires:       libucm0 = %version

%description -n libucm-devel
libucm is a standalone non-unloadable library which installs hooks
for virtual memory changes in the current process.

%package -n libucp0
Summary:        Infiniband Unified Communication Protocols
Group:          System/Libraries

%description -n libucp0
High-level API uses UCT framework to construct protocols commonly
found in applications (MPI, OpenSHMEM, PGAS, etc.)

%package -n libucp-devel
Summary:        Development files for Unified Communication Protocols (UC-P)
Group:          Development/Libraries/C and C++
Requires:       libucp0 = %version

%description -n libucp-devel
High-level API uses UCT framework to construct protocols commonly
found in applications (MPI, OpenSHMEM, PGAS, etc.)

%package -n libucs0
Summary:        Infiniband Unicified Communication Services
Group:          System/Libraries

%description -n libucs0
This framework provides basic infrastructure for component based
programming, memory management, and useful system utilities.

%package -n libucs-devel
Summary:        Development files for Unified Communication Services (UC-S)
Group:          Development/Libraries/C and C++
Requires:       libucs0 = %version

%description -n libucs-devel
This framework provides basic infrastructure for component based
programming, memory management, and useful system utilities.

%package -n libuct0
Summary:        Infiniband Unified Communication Transport
Group:          System/Libraries

%description -n libuct0
Low-level API that expose basic network operations supported by
underlying hardware.

%package -n libuct-devel
Summary:        Development files for Unified Communication Transport (UC-T)
Group:          Development/Libraries/C and C++
Requires:       libuct0 = %version

%description -n libuct-devel
Low-level API that expose basic network operations supported by
underlying hardware.

%prep
%setup -qn ucx-%version
%patch -P 1 -p1

%build
autoreconf -fi
export UCX_CFLAGS="%optflags -Wno-error"
%ifarch x86_64
export UCX_CFLAGS="$UCX_CFLAGS -mno-avx"
%endif
%ifarch %ix86
export UCX_CFLAGS="$UCX_CFLAGS -mno-sse -mno-sse2"
%endif
%configure --disable-static --without-avx --docdir="%_docdir/%name"
make %{?_smp_mflags} V=1

%post   -n libucp0 -p /sbin/ldconfig
%postun -n libucp0 -p /sbin/ldconfig
%post   -n libucs0 -p /sbin/ldconfig
%postun -n libucs0 -p /sbin/ldconfig
%post   -n libuct0 -p /sbin/ldconfig
%postun -n libuct0 -p /sbin/ldconfig
%post   -n libucm0 -p /sbin/ldconfig
%postun -n libucm0 -p /sbin/ldconfig

%install
%make_install
rm -fv "%buildroot/%_libdir"/*.la

%files tools
%defattr(-,root,root)
%_bindir/ucx_*
%_docdir/%name/
%_libdir/pkgconfig/ucx.pc
%doc LICENSE

%files -n libucm0
%defattr(-,root,root)
%_libdir/libucm.so.*

%files -n libucm-devel
%defattr(-,root,root)
%_includedir/ucm/
%_libdir/libucm.so

%files -n libucp0
%defattr(-,root,root)
%_libdir/libucp.so.*

%files -n libucp-devel
%defattr(-,root,root)
%_includedir/ucp/
%_libdir/libucp.so

%files -n libucs0
%defattr(-,root,root)
%_libdir/libucs.so.*

%files -n libucs-devel
%defattr(-,root,root)
%_includedir/ucs/
%_libdir/libucs.so

%files -n libuct0
%defattr(-,root,root)
%_libdir/libuct.so.*

%files -n libuct-devel
%defattr(-,root,root)
%_includedir/uct/
%_libdir/libuct.so

%changelog
* Sat Jan 20 2018 jengelh@inai.de
- Use right documentation path.
* Fri Jan 19 2018 nmoreychaisemartin@suse.com
- Update to 1.2.2
  - Support including UCX API headers from C++ code
  - UD transport to handle unicast flood on RoCE fabric
  - Compilation fixes for gcc 7.1.1, clang 3.6, clang 5
  - When UD transport is used with RoCE, packets intended for other peers may
    arrive on different adapters (as a result of unicast flooding).
  - This change adds packet filtering based on destination GIDs. Now the packet
    is silently dropped, if its destination GID does not match the local GID.
  - Added a new device ID for InfiniBand HCA
* Fri Dec  8 2017 dimstar@opensuse.org
- Drop doxygen BuildRequires: The documentation was already not
  built with this enabled. Removing the BR causes no regression in
  the package but eliminates a build cycle
  boost -> curl -> doxygen -> openucx -> boost
* Tue Sep 19 2017 jengelh@inai.de
- Rediff openucx-s390x-support.patch as p1 to be in line with
  potential git-generated patches.
* Tue Sep 19 2017 nmoreychaisemartin@suse.com
- Switch to version 1.2.1 (Fate#324050)
  Previous 1.3+ version was based on a development branch.
  Supported platforms
  - Shared memory: KNEM, CMA, XPMEM, SYSV, Posix
  - VERBs over InfiniBand and RoCE.
    VERBS over other RDMA interconnects (iWarp, OmniPath, etc.) is available
    for community evaluation and has not been tested in context of this release
  - Cray Gemini and Aries
  - Architectures: x86_64, ARMv8 (64bit), Power64
  Features:
  - Added support for InfiniBand DC and UD transports, including accelerated verbs for Mellanox devices
  - Full support for PGAS/SHMEM interfaces, blocking and non-blocking APIs
  - Support for MPI tag matching, both in software and offload mode
  - Zero copy protocols and rendezvous, registration cache
  - Handling transport errors
  - Flow control for DC/RC
  - Dataypes support: contiguous, IOV, generic
  - Multi-threading support
  - Support for ARMv8 64bit architecture
  - A new API for efficient memory polling
  - Support for malloc-hooks and memory registration caching
* Fri Jun 30 2017 nmoreychaisemartin@suse.com
- Disable avx at configure level
* Wed Jun 28 2017 nmoreychaisemartin@suse.com
- Add openucx-s390x-support.patch to fix compilation on s390x
- Compile openucx on s390x
* Thu Jun  8 2017 nmoreychaisemartin@suse.com
- Fix compilation on ppc
* Fri May 26 2017 jengelh@inai.de
- Update to snapshot 1.3+git44
  * No changelog was found
- Add -Wno-error and disable AVX/SSE as it is not guaranteed
  to exist.
* Sat Jun 18 2016 jengelh@inai.de
- Update to snapshot 0~git1727
  * New: libucm. libucm is a standalone non-unloadable library which
  installs hooks for virtual memory changes in the current process.
* Sun Sep 13 2015 jengelh@inai.de
- Update to snapshot 0~git862
  * License clarification on upstream's behalf
* Mon Jul 27 2015 jengelh@inai.de
- Initial package for build.opensuse.org (version 0~git713)
